Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(446)

Unified Diff: remoting/host/remoting_me2me_host.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/remoting_me2me_host.cc
diff --git a/remoting/host/remoting_me2me_host.cc b/remoting/host/remoting_me2me_host.cc
index 2b80763a2386f4ca7914706c12c136cfa9f420a9..74ce044c191511685861374f07e5a4b3db328ebf 100644
--- a/remoting/host/remoting_me2me_host.cc
+++ b/remoting/host/remoting_me2me_host.cc
@@ -205,8 +205,8 @@ class HostProcess
// STOPPING->STOPPED
// STOPPED->STARTED
//
// |host_| must be NULL in INITIALIZING and STOPPED states and not-NULL in
// all other states.
};
friend class base::RefCountedThreadSafe<HostProcess>;
@@ -385,7 +385,7 @@ HostProcess::HostProcess(scoped_ptr<ChromotingHostContext> context,
enable_window_capture_(false),
window_id_(0),
#if defined(REMOTING_MULTI_PROCESS)
- desktop_session_connector_(NULL),
+ desktop_session_connector_(nullptr),
#endif // defined(REMOTING_MULTI_PROCESS)
self_(this),
exit_code_out_(exit_code_out),
@@ -782,14 +782,14 @@ void HostProcess::ShutdownOnUiThread() {
desktop_environment_factory_.reset();
// It is now safe for the HostProcess to be deleted.
- self_ = NULL;
+ self_ = nullptr;
#if defined(OS_LINUX)
// Cause the global AudioPipeReader to be freed, otherwise the audio
// thread will remain in-use and prevent the process from exiting.
// TODO(wez): DesktopEnvironmentFactory should own the pipe reader.
// See crbug.com/161373 and crbug.com/104544.
- AudioCapturerLinux::InitializePipeReader(NULL, base::FilePath());
+ AudioCapturerLinux::InitializePipeReader(nullptr, base::FilePath());
#endif
}
@@ -833,7 +833,7 @@ void HostProcess::InitializePairingRegistry(
IPC::PlatformFileForTransit privileged_key,
IPC::PlatformFileForTransit unprivileged_key) {
DCHECK(context_->network_task_runner()->BelongsToCurrentThread());
// |privileged_key| can be NULL but not |unprivileged_key|.
DCHECK(unprivileged_key);
// |pairing_registry_| should only be initialized once.
DCHECK(!pairing_registry_);
@@ -1510,7 +1510,7 @@ int HostProcessMain() {
// Required for any calls into GTK functions, such as the Disconnect and
// Continue windows, though these should not be used for the Me2Me case
// (crbug.com/104377).
- gtk_init(NULL, NULL);
+ gtk_init(nullptr, nullptr);
#endif
// Enable support for SSL server sockets, which must be done while still
« no previous file with comments | « remoting/host/register_support_host_request_unittest.cc ('k') | remoting/host/resizing_host_observer_unittest.cc » ('j') | no next file with comments »
@@ -205,8 +205,8 @@ class HostProcess
// STOPPED->STARTED
//
- // |host_| must be NULL in INITIALIZING and STOPPED states and not-NULL in
- // all other states.
+ // |host_| must be nullptr in INITIALIZING and STOPPED states and not
+ // nullptr in all other states.
};
friend class base::RefCountedThreadSafe<HostProcess>;
@@ -833,7 +833,7 @@ void HostProcess::InitializePairingRegistry(
IPC::PlatformFileForTransit unprivileged_key) {
DCHECK(context_->network_task_runner()->BelongsToCurrentThread());
- // |privileged_key| can be NULL but not |unprivileged_key|.
+ // |privileged_key| can be nullptr but not |unprivileged_key|.
DCHECK(unprivileged_key);
// |pairing_registry_| should only be initialized once.

Powered by Google App Engine
This is Rietveld 408576698